package solutions.bitbadger.documents.support

import solutions.bitbadger.documents.extensions.insert

/** The test table name to use for integration tests */
const val TEST_TABLE = "test_table"

data class NumIdDocument(val key: Int, val text: String) {
    constructor() : this(0, "")
}

data class SubDocument(val foo: String, val bar: String) {
    constructor() : this("", "")
}

data class ArrayDocument(val id: String, val values: List<String>) {

    constructor() : this("", listOf())

    companion object {
        /** A set of documents used for integration tests */
        val testDocuments = listOf(
            ArrayDocument("first",  listOf("a", "b", "c")),
            ArrayDocument("second", listOf("c", "d", "e")),
            ArrayDocument("third",  listOf("x", "y", "z"))
        )
    }
}

data class JsonDocument(val id: String, val value: String = "", val numValue: Int = 0, val sub: SubDocument? = null) {

    constructor() : this("")

    companion object {
        /** Documents to use for testing */
        private val testDocuments = listOf(
            JsonDocument("one",   "FIRST!",   0, null),
            JsonDocument("two",   "another", 10, SubDocument("green", "blue")),
            JsonDocument("three", "",         4, null),
            JsonDocument("four",  "purple",  17, SubDocument("green", "red")),
            JsonDocument("five",  "purple",  18, null)
        )

        fun load(db: ThrowawayDatabase, tableName: String = TEST_TABLE) =
            testDocuments.forEach { db.conn.insert(tableName, it) }
    }
}

// Test classes for AutoId generation

data class ByteIdClass(val id: Byte)
data class ShortIdClass(val id: Short)
data class IntIdClass(val id: Int)
data class LongIdClass(val id: Long)
data class StringIdClass(val id: String)
